@@ -2,6 +2,10 @@
 #' @importFrom magrittr %>%
 magrittr::`%>%`
 
+#' @export
+#' @importFrom tibble as_tibble
+tibble::as_tibble
+
 #' @export
 #' @importFrom knitr knit_print
 knitr::knit_print
