@@ -17,34 +17,62 @@
 #' or `broom.mixed::tidy`.
 #' @param conf.level confidence level passed directly to `broom::tidy`
 #' or `broom.mixed::tidy`.
+#' @param tidy_fun tidy function and arguments passed to it
 #' @noRd
 #' @keywords internal
 #' @author Daniel D. Sjoberg
 
 # Points function to use mixed vs non-mixed version of broom
-tidy_wrap <- function(x, exponentiate, conf.level) {
-  mixed_classes <- c("lmerMod", "glmerMod", "nlme")
-  if (class(x)[1] %in% mixed_classes) { # can add other classes later. Need exact subclass.
-    tidy_bit <- broom.mixed::tidy(
-      x,
-      exponentiate = exponentiate,
-      conf.level = conf.level, conf.int = T, effects = "fixed"
-    )
+tidy_wrap <- function(x, exponentiate, conf.level, tidy_fun) {
+  mixed_classes <- c("lmerMod", "glmerMod")
+  if (is.null(tidy_fun)) {
+    if (class(x)[1] %in% mixed_classes) { # can add other classes later. Need exact subclass.
+      tidy_bit <- broom.mixed::tidy(
+        x,
+        exponentiate = exponentiate,
+        conf.level = conf.level, conf.int = TRUE, effects = "fixed"
+      )
+    }
+
+    if (!(class(x)[1] %in% mixed_classes)) {
+      tidy_bit <- broom::tidy(
+        x,
+        exponentiate = exponentiate,
+        conf.level = conf.level, conf.int = TRUE
+      )
+    }
+
+    # deleting scale parameters from survreg objects
+    if (class(x)[1] == "survreg") {
+      return(
+        tidy_bit %>%
+          filter(!!parse_expr('term != "Log(scale)"'))
+      )
+    }
   }
 
-  if (!(class(x)[1] %in% mixed_classes)) {
-    tidy_bit <- broom::tidy(
-      x,
-      exponentiate = exponentiate,
-      conf.level = conf.level, conf.int = T
-    )
-  }
-
-  # deleting scale parameters from survreg objects
-  if (class(x)[1] == "survreg") {
-    return(
-      tidy_bit %>%
-        filter(!!parse_expr('term != "Log(scale)"'))
+  # if user specified a tidier use it here.
+  if (!is.null(tidy_fun)) {
+    tryCatch(
+      {
+        tidy_bit <- do.call(
+          tidy_fun,
+          args = list(x,
+            exponentiate = exponentiate,
+            conf.level = conf.level, conf.int = T
+          )
+        )
+      },
+      error = function(e) {
+        usethis::ui_oops(paste0(
+          "There was an error calling {usethis::ui_code('tidy_fun')}.\n",
+          "Most likely, this is because the argument passed in {usethis::ui_code('tidy_fun = ')} \n",
+          "was\nmisspelled, does not exist, is not compatible with your object, \n",
+          "or was missing necessary arguments. See error message below. \n"
+        ))
+        print(e)
+        stop(e)
+      }
     )
   }
 
@@ -71,6 +99,16 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
   # extracting model frame
   model_frame <- stats::model.frame(fit)
 
+  # add a check on what the model.frame output is and print a message if it's not
+  # a data.frame with all vector columns
+  if (!(all("data.frame" %in% class(model_frame) && all(purrr::map_lgl(model_frame, ~ rlang::is_vector(.x)))))) {
+    message(paste0(
+      "Model input `x` has an unexpected format for `model.frame(x)` \n",
+      " which may affect `tbl_regression()` output.\n",
+      "Expected `model.frame` format is a data frame with vector elements."
+    ))
+  }
+
   # all terms in model ---------------------------------------------------------
   # this code looks over the model terms, and extracts a list of each term
   # for interaction terms, the terms are reported separately
@@ -160,14 +198,18 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
   # more  var labels -----------------------------------------------------------
   # model.frame() strips variable labels from cox models.  this attempts
   # to grab the labels in another way
-  labels_parent_frame <- tryCatch({
-    stats::model.frame.default(fit) %>%
-      purrr::imap(~ attr(.x, "label"))
-  }, warning = function(w) {
-    NULL
-  }, error = function(e) {
-    NULL
-  })
+  labels_parent_frame <- tryCatch(
+    {
+      stats::model.frame.default(fit) %>%
+        purrr::imap(~ attr(.x, "label"))
+    },
+    warning = function(w) {
+      NULL
+    },
+    error = function(e) {
+      NULL
+    }
+  )
 
   # tidy_long ------------------------------------------------------------------
   # this is one line per term, AND interaction terms have one row per variable in the interaction
@@ -289,12 +331,13 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
   # show_single_row check ------------------------------------------------------
   # checking that all variables listed in show_single_row appear in results
   for (i in show_single_row) {
-    if (!i %in% tidy_group$group)
+    if (!i %in% tidy_group$group) {
       stop(glue(
         "'{i}' from argument 'show_single_row' is not a variable ",
         "from the model. Select from:\n",
         "{paste(tidy_group$group %>% setdiff('(Intercept)'), collapse = ', ')}"
       ))
+    }
   }
 
   # check that all variables in show_single_row are dichotomous
@@ -308,11 +351,11 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
     ) %>%
     filter(.data$bad_show_single_row == TRUE) %>%
     pull(.data$group)
-  if (length(bad_show_single_row) > 0 ) {
-      stop(glue(
-        "'{paste(bad_show_single_row, collapse = \"', '\")}' from argument ",
-        "'show_single_row' may only be applied to binary variables."
-      ))
+  if (length(bad_show_single_row) > 0) {
+    stop(glue(
+      "'{paste(bad_show_single_row, collapse = \"', '\")}' from argument ",
+      "'show_single_row' may only be applied to binary variables."
+    ))
   }
 
   # final touches to result ----------------------------------------------------
@@ -411,3 +454,28 @@ parse_final_touches <- function(group, group_lbl, single_row, var_type, data, mo
       "estimate", "conf.low", "conf.high", "p.value"
     ))
 }
+
+#' @title Vetted tidy models
+#'
+#' @description Below is a list of models vetted for use
+#' in [tbl_regression] and [tbl_uvregression].  If a model is passed to these
+#' functions and the model is not listed below and  a `tidy()` function is
+#' not specified in the `tidy_fun=` argument, the model object will be passed
+#' to [broom::tidy].
+#'
+#' \itemize{
+#'  \item{[stats::lm]}
+#'  \item{[stats::glm]}
+#'  \item{[survival::coxph]}
+#'  \item{[survival::survreg]}
+#'  \item{[lme4::glmer]}
+#'  \item{[lme4::lmer]}
+#'  \item{[geepack::geeglm]}
+#' }
+#' @name tidy_vetted
+#' @section model support:
+#' If [broom::tidy] or [broom.mixed::tidy] support a class of model not listed
+#' above, please submit a [GitHub Issue](https://github.com/ddsjoberg/gtsummary/issues).
+#' The model can be added to the list of vetted models and unit tests will be
+#' put in place to ensure continued support for the model.
+NULL
