@@ -13,15 +13,22 @@ test_that("no errors/warnings with standard use", {
   expect_warning(t1 %>% add_n(last = TRUE), NA)
   expect_warning(t2 %>% add_n(last = TRUE), NA)
 
-  expect_error(t1 %>% add_n(statistic = "{N}{n}{n_miss}{p}{p_miss}",
-                            footnote = TRUE), NA)
-  expect_error(t2 %>% add_n(statistic = "{N}{n}{n_miss}{p}{p_miss}",
-                            footnote = TRUE), NA)
-  expect_warning(t1 %>% add_n(statistic = "{N}{n}{n_miss}{p}{p_miss}",
-                              footnote = TRUE), NA)
-  expect_warning(t2 %>% add_n(statistic = "{N}{n}{n_miss}{p}{p_miss}",
-                              footnote = TRUE), NA)
-
+  expect_error(t1 %>% add_n(
+    statistic = "{N}{n}{n_miss}{p}{p_miss}",
+    footnote = TRUE
+  ), NA)
+  expect_error(t2 %>% add_n(
+    statistic = "{N}{n}{n_miss}{p}{p_miss}",
+    footnote = TRUE
+  ), NA)
+  expect_warning(t1 %>% add_n(
+    statistic = "{N}{n}{n_miss}{p}{p_miss}",
+    footnote = TRUE
+  ), NA)
+  expect_warning(t2 %>% add_n(
+    statistic = "{N}{n}{n_miss}{p}{p_miss}",
+    footnote = TRUE
+  ), NA)
 })
 
 
