@@ -30,19 +30,19 @@ test_that("inline_text.tbl_summary: no by", {
 
 test_that("inline_text.tbl_summary: with by", {
   expect_error(
-    inline_text(test_inline2, variable = "age", column = "Placebo"),
+    inline_text(test_inline2, variable = "age", column = "Drug B"),
     NA
   )
   expect_warning(
-    inline_text(test_inline2, variable = "age", column = "Placebo"),
+    inline_text(test_inline2, variable = "age", column = "Drug B"),
     NA
   )
   expect_error(
-    inline_text(test_inline2, variable = "stage", level = "T1", column = "Placebo"),
+    inline_text(test_inline2, variable = "stage", level = "T1", column = "Drug B"),
     NA
   )
   expect_warning(
-    inline_text(test_inline2, variable = "stage", level = "T1", column = "Placebo"),
+    inline_text(test_inline2, variable = "stage", level = "T1", column = "Drug B"),
     NA
   )
   expect_error(
@@ -62,12 +62,12 @@ test_that("inline_text.tbl_summary: with by -  expect errors", {
     "No column selected.*"
   )
   expect_error(
-    inline_text(test_inline2, variable = "stage", level = "Tsdfgsdfg1", column = "Placebo"),
+    inline_text(test_inline2, variable = "stage", level = "Tsdfgsdfg1", column = "Drug B"),
     "Is the variable level spelled correctly.*"
   )
 
   expect_error(
-    inline_text(test_inline2, variable = "st55age", level = "T1", column = "Placebo"),
+    inline_text(test_inline2, variable = "st55age", level = "T1", column = "Drug B"),
     "Is the variable name spelled correctly.*"
   )
 })
@@ -140,19 +140,19 @@ test_inline_surv_nostrata2 <-
 # test tbl_survival with strata
 test_that("inline_text.tbl_survival - with strata", {
   expect_error(
-    inline_text(test_inline_surv_strata, strata = "Drug", time = 24),
+    inline_text(test_inline_surv_strata, strata = "Drug B", time = 24),
     NA
   )
   expect_error(
-    inline_text(test_inline_surv_strata2, strata = "Drug", prob = 0.2),
+    inline_text(test_inline_surv_strata2, strata = "Drug B", prob = 0.2),
     NA
   )
   expect_message(
-    inline_text(test_inline_surv_strata, strata = "Drug", time = 30),
+    inline_text(test_inline_surv_strata, strata = "Drug B", time = 30),
     "Specified 'time'*"
   )
   expect_error(
-    inline_text(test_inline_surv_strata, strata = "Drug", time = -2),
+    inline_text(test_inline_surv_strata, strata = "Drug B", time = -2),
     "Must specify a positive 'time'."
   )
   expect_error(
@@ -176,7 +176,7 @@ test_that("inline_text.tbl_survival - no strata", {
     NA
   )
   expect_warning(
-    inline_text(test_inline_surv_nostrata, strata = "Drug", time = 24),
+    inline_text(test_inline_surv_nostrata, strata = "Drug B", time = 24),
     "Ignoring strata =*"
   )
 })
