@@ -66,8 +66,12 @@ test_that("Stacking tbl_merge objects", {
 })
 
 test_that("Stacking tbl_summary objects", {
-  yy <- tbl_summary(trial, by = response) %>% add_p() %>% add_q()
-  tt <- tbl_summary(trial, by = trt) %>% add_p() %>% add_q()
+  yy <- tbl_summary(trial, by = response) %>%
+    add_p() %>%
+    add_q()
+  tt <- tbl_summary(trial, by = trt) %>%
+    add_p() %>%
+    add_q()
 
   expect_error(
     zz <- tbl_stack(list(yy, tt)),
