@@ -16,6 +16,21 @@ test_that("lm: no errors/warnings with standard use", {
     ), NA)
 })
 
+test_that("lm specifying tidy_fun: no errors/warnings with standard use", {
+  expect_error(mtcars %>%
+    tbl_uvregression(
+      method = lm,
+      y = mpg,
+      tidy_fun = broom::tidy
+    ), NA)
+  expect_warning(mtcars %>%
+    tbl_uvregression(
+      method = lm,
+      y = mpg,
+      tidy_fun = broom::tidy
+    ), NA)
+})
+
 test_that("coxph: no errors/warnings with standard use", {
   expect_error(
     coxph_uv <-
@@ -23,13 +38,15 @@ test_that("coxph: no errors/warnings with standard use", {
       tbl_uvregression(
         method = coxph,
         y = Surv(time, status)
-      ), NA)
+      ), NA
+  )
   expect_warning(
     lung %>%
       tbl_uvregression(
         method = coxph,
         y = Surv(time, status)
-      ), NA)
+      ), NA
+  )
 
   expect_identical(
     coxph_uv$meta_data$variable,
@@ -137,6 +154,15 @@ test_that("tbl_uvregression creates errors with bad inputs", {
     ),
     "*"
   )
+  expect_error(
+    tbl_uvregression(
+      data = mtcars,
+      method = coxph,
+      y = Surv(time, status),
+      tidy_fun = mtcars
+    ),
+    "*"
+  )
   expect_error(
     tbl_uvregression(
       data = lung,
